@@ -23,33 +23,40 @@ def get_user_from_session(request):
     return request.session.get('profile')
 
 
+def get_accounts_client(request):
+    """Create a helper function for returning an accounts client
+    with the user's access token
+    """
+    client = request.registry.getUtility(IOpenstaxAccounts, 'factory')()
+    access_token = request.session.get('access_token')
+    if access_token:
+        client.access_token = access_token
+    return client
+
+
 @implementer(IAuthenticationPolicy)
 class OpenstaxAccountsAuthenticationPolicy(object):
 
-    def __init__(self, client_factory, client_args, application_url,
-            login_path, callback_path, logout_path):
-        self.client_factory = client_factory
-        self.client_args = client_args
+    def __init__(self, application_url, login_path, callback_path, logout_path):
         self.application_url = application_url
         self.login_path = login_path
         self.callback_path = callback_path
         self.logout_path = logout_path
 
     def _login(self, request):
-        client = self.client_factory(*self.client_args)
-        raise HTTPFound(location=client.auth_uri())
+        raise HTTPFound(location=request.accounts_client.auth_uri())
 
     def authenticated_userid(self, request):
         if request.path == self.login_path:
             return self._login(request)
         if request.path == self.callback_path:
             code = request.params['code']
-            client = self.client_factory(*self.client_args)
-            client.request_token_with_code(code)
-            me = client.request('/api/user.json')
+            request.accounts_client.request_token_with_code(code)
+            me = request.accounts_client.get_profile()
             request.session.update({
                 'profile': me,
                 'username': me.get('username'),
+                'access_token': request.accounts_client.access_token,
                 })
             request.session.changed()
             return me.get('username')
@@ -71,8 +78,8 @@ class OpenstaxAccountsAuthenticationPolicy(object):
 
     def forget(self, request):
         if self.unauthenticated_userid(request):
-            client = self.client_factory(*self.client_args)
-            logout_url = urlparse.urljoin(client.server_url, '/logout')
+            logout_url = urlparse.urljoin(request.accounts_client.server_url,
+                                          '/logout')
             return_to = urlparse.urljoin(self.application_url, self.logout_path)
             params = urlencode({'return_to': return_to})
             request.session.clear()
@@ -81,13 +88,10 @@ class OpenstaxAccountsAuthenticationPolicy(object):
 
 def main(config):
     config.add_request_method(get_user_from_session, 'user', reify=True)
+    config.add_request_method(get_accounts_client, 'accounts_client',
+                              reify=True)
     settings = config.registry.settings
     config.registry.registerUtility(OpenstaxAccountsAuthenticationPolicy(
-        client_factory=config.registry.getUtility(IOpenstaxAccounts, 'factory'),
-        client_args=(settings['openstax_accounts.server_url'],
-                     settings['openstax_accounts.application_id'],
-                     settings['openstax_accounts.application_secret'],
-                     settings['openstax_accounts.application_url']),
         application_url=settings['openstax_accounts.application_url'],
         login_path=settings['openstax_accounts.login_path'],
         callback_path=settings['openstax_accounts.callback_path'],
